#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# keyfile_dialog.pyw
# 
# the user should give us a keyfile
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2014 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import base64
import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

from ui_KeyfileDialog import Ui_KeyfileDialog 
from about_dialog import AboutDialog


# ------------------------------------------------------------
# code


class KeyfileDialog(QtGui.QDialog):

    """A dialog for letting the user pass on a password/keyfile combo"""

    def __init__(self, user_text = 'Please provide an approbitate password and keyfile to proceed:'):

        QtGui.QDialog.__init__(self)

        # setup the user interface
        self.ui = Ui_KeyfileDialog()
        self.ui.setupUi(self)
    
        # local members
        self._about_dialog = AboutDialog()
        self._open_file_dialog = QtGui.QFileDialog(self, 'Open Keyfile', QtCore.QDir.homePath(), 'All Files (*.*);;')
        self._open_file_dialog.setAcceptMode(QtGui.QFileDialog.AcceptOpen)
        self._open_file_dialog.setFileMode(QtGui.QFileDialog.ExistingFile)

        # connectors
        self.ui.lblText.setText(user_text)
        self.ui.btnAbout.clicked.connect(self.clicked_about)
        self.ui.btnCancel.clicked.connect(self.reject)
        self.ui.btnOk.clicked.connect(self.clicked_ok)
        self.ui.btnBrowse.clicked.connect(self.clicked_browse)

        # positionate ourself central
        screen = QtGui.QDesktopWidget().screenGeometry()
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2, (screen.height() - size.height()) / 2)
 

    def clicked_about(self):

        """About button has been clicked."""
        self._about_dialog.show()


    def clicked_browse(self):

        """Browse button has been clicked."""
        if self._open_file_dialog.exec_() == QtGui.QDialog.Accepted:
            self.ui.edtKeyfile.setText(self._open_file_dialog.selectedFiles()[0])


    def clicked_ok(self):
        
        """Ok button has been clicked."""

        # read the content of the keyfile
        keyfile_content = ''
        try:
            keyfile = open(self.ui.edtKeyfile.text(), 'r')
            keyfile_content = keyfile.read()
        except Exception as e:
            sys.stderr.write('failed to read keyfile content:\n' + str(e) + '\n')
            QtGui.QMessageBox.critical(self, 'Failed to read keyfile', str(e))
            return

        # turn into Base64
        keyfile_content_base64 = base64.b64encode(keyfile_content)

        sys.stdout.write('{ ')
        sys.stdout.write('"password": "')
        sys.stdout.write(self.ui.edtPassword.text())
        sys.stdout.write('", ')
        sys.stdout.write('"keyfile": "')
        sys.stdout.write(keyfile_content_base64)
        sys.stdout.write('" ')
        sys.stdout.write('}\n')
        self.accept()


    def set_user_text(user_text):

        """Set a text to explain which password we need."""
        self.ui.lblText.setText(user_text)


if __name__ == "__main__":
    a = QtGui.QApplication(sys.argv)
    d = KeyfileDialog()
    d.show()
    sys.exit(a.exec_())     

